@@ -6,7 +6,7 @@ Rubric::Config - the configuration data for a Rubric
 
 =head1 VERSION
 
- $Id: Config.pm,v 1.6 2004/12/13 18:32:13 rjbs Exp $
+ $Id: Config.pm,v 1.10 2004/12/20 13:24:04 rjbs Exp $
 
 =head1 DESCRIPTION
 
@@ -23,6 +23,13 @@ use base qw(Class::Accessor);
 use Config::Auto;
 use YAML;
 
+my $config_filename = 'rubric.yml';
+
+sub import {
+	my ($class) = shift;
+	$config_filename = shift if @_;
+}
+
 =head1 METHODS
 
 =head2 read_config
@@ -36,7 +43,7 @@ my $config;
 sub read_config {
 	return $config if $config;
 
-	my $config_file = Config::Auto::find_file('rubric.yml');
+	my $config_file = Config::Auto::find_file($config_filename);
 	$config = YAML::LoadFile($config_file);
 }
 
@@ -49,7 +56,10 @@ __PACKAGE__->mk_ro_accessors(qw(
 	css_href
 	dsn
 	email_from
+	login_class
+	private_system
 	registration_closed
+	skip_newuser_verification
 	smtp_server
 	template_path
 	uri_root
@@ -60,6 +70,12 @@ __PACKAGE__->mk_ro_accessors(qw(
 This method returns the DSN to be used by Rubric::DBI to connect to the
 Rubric's database.
 
+=head2 login_class
+
+This is the class used to check for logins; it should subclass
+Rubric::WebApp::Login.  If not supplied, the default is
+Rubric::WebApp::Login::Post.
+
 =head2 uri_root
 
 This method returns the URI for the root of the Rubric::WebApp install.
@@ -69,6 +85,11 @@ This method returns the URI for the root of the Rubric::WebApp install.
 This method returns the URI for the stylesheet to be used by Rubric::WebApp
 pages.
 
+=head2 skip_newuser_verification
+
+If true, users will be created without verification codes, and won't get
+verification emails.
+
 =head2 template_path
 
 This method returns the INCLUDE_PATH passed to Template when creating the
@@ -86,6 +107,12 @@ This method returns the SMTP server used to send email.
 
 This method returns a true value if registration isn't open to the world.
 
+=head2 private_system
+
+This method returns a true value if the Rubric is private.  A private Rubric
+restricts unauthenticated sessions to logging in or registering an account (and
+if registration is closed, they can only log in).
+
 =head1 TODO
 
 =head1 AUTHOR
