@@ -6,7 +6,7 @@ Rubric::Entry - a single entry made by a user
 
 =head1 VERSION
 
- $Id: Entry.pm,v 1.14 2004/12/13 21:40:10 rjbs Exp $
+ $Id: Entry.pm,v 1.16 2004/12/19 19:14:34 rjbs Exp $
 
 =head1 DESCRIPTION
 
@@ -136,6 +136,7 @@ The arguments to C<by_tag> indicate the tags and users for which to search.
 
  user - the user whose tags to search (can be undef)
  tags - an arrayref of tag names
+ link - the id of the entry's link
  has_body - whether entries must have bodies (T, F, or undef)
  has_link - whether entries must have a link (T, F, or undef)
 
@@ -192,6 +193,7 @@ letters, numbers, underscores, colons, dots, and asterisks.
 
 sub tags_from_string {
 	my ($class, $taglist) = @_;
+	$taglist =~ /^([\s\w\d:.*]+)$/; $taglist = $1;
 	[ grep /^[\w\d:.*]+$/, split /\s+/, $taglist ];
 }
 
