@@ -6,13 +6,13 @@ Rubric::WebApp - the web interface to Rubric
 
 =head1 VERSION
 
-version 0.00_25
+version 0.02_1
 
- $Id: WebApp.pm,v 1.52 2004/12/16 04:55:40 rjbs Exp $
+ $Id: WebApp.pm,v 1.58 2004/12/20 13:36:13 rjbs Exp $
 
 =cut
 
-our $VERSION = '0.00_25';
+our $VERSION = '0.02_01';
 
 =head1 SYNOPSIS
 
@@ -39,6 +39,7 @@ basic dispatch table looks something like this:
  -------------+-------------------------------------------+--------------
  /login       | log in to a user account                  | login
  /logout      | log out                                   | logout
+ /preferences | view or change account settings           | preferences
  /newuser     | create a new user account                 | newuser
  /verify      | verify a pending user account             | verify
  /link        | view the details of entries for a link    | link
@@ -118,9 +119,12 @@ paging, and starts processing the request path.
 sub cgiapp_init {
 	my ($self) = @_;
 
-	$self->session_config(COOKIE_PARAMS => { -expires => '+3d' });
-	$self->check_for_login;
-	$self->get_current_user;
+	$self->session_config( COOKIE_PARAMS => { -expires => '+7d' } );
+	
+	my $login_class = Rubric::Config->login_class || 'Rubric::WebApp::Login::Post';
+	eval "require $login_class";
+	$login_class->check_for_login($self);
+
 	$self->check_pager_data;
 
 	my @path = split '/', $self->query->path_info;
@@ -128,52 +132,6 @@ sub cgiapp_init {
 	$self->param(path => \@path);
 }
 
-=head2 check_for_login
-
-This method is called by C<cgiapp_init>, and checks for a login attempt in the
-submitted request.  A login request is made with two CGI parameters:
-
- user     - the user's username
- password - the user's password
-
-If these match, the user is now logged in.  If not, it is ignored.
-
-However!  If the REMOTE_USER environment variable is set, because the user has
-logged in via HTTP, the value of REMOTE_USER is used as the current user.
-
-=cut
-
-sub check_for_login {
-	my ($self) = @_;
-
-	return $self->session->param('current_user', $ENV{REMOTE_USER})
-		if ($ENV{REMOTE_USER});
-
-	return unless my $userid = $self->query->param('user');
-	return unless my $login_user = Rubric::User->retrieve($userid);
-
-	my $login_pass = $self->query->param('password');
-	if (md5_hex($login_pass) eq $login_user->password) {
-		$login_user->verification_code
-			? $self->param('user_pending', 1)
-			: $self->session->param('current_user',$self->query->param('user'))
-	}
-}
-
-=head2 get_current_user
-
-This method is called by C<cgiapp_init>, and retrieves the Rubric::User object
-for the currently logged-in user, if any.
-
-=cut
-
-sub get_current_user {
-	my ($self) = @_;
-
-	return unless my $userid = $self->session->param('current_user');
-	$self->param(current_user => Rubric::User->retrieve($userid));
-}
-
 =head2 check_pager_data
 
 This method is called by C<cgiapp_init>, and sets up parameters used for paging
@@ -227,7 +185,7 @@ sub template {
 	my ($content_type, $output) =
 		Rubric::Renderer->process($template, $type, $stash);
 
-	$self->header_props(-type => $content_type);
+	$self->header_add(-type => $content_type);
 	return $output;
 }
 
@@ -249,7 +207,7 @@ sub setup {
 	if ($self->param('current_user') or not Rubric::Config->private_system) {
 		$self->start_mode('recent');
 		$self->run_modes([
-			qw(delete edit entry link logout post recent user tag)
+			qw(delete edit entry link logout post preferences recent user tag)
 		]);
 	}
 
@@ -360,6 +318,79 @@ sub logout {
 	return $self->redirect_root("Logged out...");
 }
 
+=head2 preferences
+
+This method displays account information for the current user.  Some account
+settings may be changed.
+
+=cut
+
+sub preferences {
+	my ($self) = @_;
+
+	return $self->redirect_root("permission denied")
+		unless $self->param('current_user');
+	
+	my %prefs  = $self->_get_prefs_form;
+	return $self->template("preferences") unless %prefs;
+
+	my %errors = $self->validate_prefs(\%prefs);
+	return $self->template("preferences", { %prefs, %errors } ) if %errors;
+
+	$self->update_user(\%prefs);
+}
+
+sub update_user {
+	my ($self, $prefs) = @_;
+	for ($self->param('current_user')) {
+		$_->password(md5_hex($prefs->{password_1})) if $prefs->{password_1};
+		$_->email($prefs->{email});
+		$_->update;
+	}
+	$self->redirect_root('updated');
+}
+
+sub _get_prefs_form {
+	my ($self) = @_;
+
+	my %form;
+	for (qw(password password_1 password_2 email)) {
+		$form{$_} = $self->query->param($_) if $self->query->param($_);
+	}
+	return %form;
+}
+
+sub validate_prefs {
+	my ($self, $prefs) = @_;
+	my %errors;
+
+	unless ($prefs->{email}) {
+		$errors{email_missing} = 1;
+	} elsif ($prefs->{email} and $prefs->{email} !~ $Email::Address::addr_spec) {
+		undef $prefs->{email};
+		$errors{email_invalid} = 1;
+	}
+
+	if (
+		$prefs->{password_1} and $prefs->{password_2}
+		and $prefs->{password_1} ne $prefs->{password_2}
+	) {
+		undef $prefs->{password_1};
+		undef $prefs->{password_2};
+		$errors{password_mismatch} = 1;
+	}
+
+	unless ($prefs->{password}) {
+		$errors{password_missing} = 1;
+	} elsif (
+		md5_hex($prefs->{password}) ne $self->param('current_user')->password
+	) {
+		$errors{password_wrong} = 1;
+	}
+
+	return %errors;
+}
+
 =head2 newuser
 
 If the proper form information is present, this runmode creates a new user
@@ -385,7 +416,7 @@ sub newuser {
 
 	my %errors = $self->validate_newuser_form(\%newuser);
 	if (%errors) {
-		$self->template('newuser' => { %newuser, %errors});
+		$self->template('newuser' => { %newuser, %errors });
 	} else {
 		$self->create_newuser(%newuser);
 	}
@@ -424,22 +455,33 @@ sub validate_newuser_form {
 sub create_newuser {
 	my ($self, %newuser) = @_;
 
-	my $user = Rubric::User->create({
+	my %user = (
 		username => $newuser{username},
 		password => md5_hex($newuser{password_1}),
 		email    => $newuser{email},
-		verification_code => md5_hex("%newuser".time)
-	});
+	);
 
-	Rubric::Renderer->renderer('txt')->process(
-		'newuser_mail.txt',
-		{ user => $user, email_from => Rubric::Config->email_from },
-		\(my $message)
+	$user{verification_code} = md5_hex("%user".time)
+		unless Rubric::Config->skip_newuser_verification;
+
+	my $user = Rubric::User->create(\%user);
+
+	$self->send_verification_email_to($user)
+		unless Rubric::Config->skip_newuser_verification;
+
+	$self->template("account_created");
+}
+
+sub send_verification_email_to {
+	my ($self, $user) = @_;
+
+	my $message = Rubric::Renderer->process(
+		'newuser_mail',
+		'txt',
+		{ user => $user, email_from => Rubric::Config->email_from }
 	);
 
 	send SMTP => $message => Rubric::Config->smtp_server;
-
-	$self->template("account_created");
 }
 
 =head2 verify
@@ -514,9 +556,12 @@ sub tag {
 sub get_tags {
 	my ($self) = @_;
 
-	my $tags = shift @{$self->param('path')};
-
-	$self->param(tags => [ split /\+/, ($tags || '') ]);
+	if (my $tags = shift @{$self->param('path')}) {
+		$tags =~ /^([+\s\w\d:.*]+)$/; $tags = $1;
+		$self->param(tags => [ split /\+/, $tags ]);
+	} else {
+		$self->param(tags => [ ]);
+	}
 
 	return $self;
 }
